@@ -7,7 +7,7 @@ use Kavorka::Signature ();
 package Kavorka::Sub;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.003';
+our $VERSION   = '0.004';
 
 use Text::Balanced qw( extract_codeblock extract_bracketed );
 use Parse::Keyword {};
@@ -29,6 +29,8 @@ has qualified_name  => (is => 'rwp');
 
 sub allow_anonymous { 1 }
 
+sub invocation_style { +undef }
+
 sub parse
 {
 	my $class = shift;
@@ -365,6 +367,12 @@ This makes sense to override if the sub shouldn't be installed in the
 normal Perlish way. For example L<Kavorka::MethodModifier> overrides
 it.
 
+=item C<invocation_style>
+
+Returns a string "fun" or "method" depending on whether subs are
+expected to be invoked as functions or methods. May return undef if
+neither is really the case (e.g. as with method modifiers).
+
 =back
 
 =head1 BUGS
